{#
    basic/domainindex.html
    ~~~~~~~~~~~~~~~~~~~~~~

    Template for domain indices (module index, ...).

    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
#}
{% extends "layout.html" %}
{% set title = indextitle %}
{% block extrahead %}
{{ super() }}
{% if not embedded and collapse_index %}
    <script type="text/javascript">
      DOCUMENTATION_OPTIONS.COLLAPSE_INDEX = true;
    </script>
{% endif %}
{% endblock %}
{% block body %}
<div class="section">
   {%- set curr_group = 0 %}

   <h1>{{ indextitle }}</h1>

   <div class="modindex-jumpbox">
   {%- for (letter, entries) in content %}
   <a href="#cap-{{ letter }}"><strong>{{ letter }}</strong></a>
     {%- if not loop.last %} | {% endif %}
   {%- endfor %}
   </div>

   <table class="indextable modindextable" cellspacing="0" cellpadding="2">
   {%- for letter, entries in content %}
     <tr class="pcap"><td></td><td>&nbsp;</td><td></td></tr>
     <tr class="cap"><td></td><td><a name="cap-{{ letter }}">
           <strong>{{ letter }}</strong></a></td><td></td></tr>
     {%- for (name, grouptype, page, anchor, extra, qualifier, description)
             in entries %}
     {%- if grouptype == 1 %}{% set curr_group = curr_group + 1 %}{% endif %}
     <tr{% if grouptype == 2 %} class="cg-{{ curr_group }}"{% endif %}>
       <td>{% if grouptype == 1 -%}
         <img src="{{ pathto('_static/minus.png', 1) }}" id="toggle-{{ curr_group }}"
              class="toggler" style="display: none" alt="-" />
           {%- endif %}</td>
       <td>{% if grouptype == 2 %}&nbsp;&nbsp;&nbsp;{% endif %}
       {% if page %}<a href="{{ pathto(page) }}#{{ anchor }}">{% endif -%}
       <tt class="xref">{{ name|e }}</tt>
       {%- if page %}</a>{% endif %}
     {%- if extra %} <em>({{ extra|e }})</em>{% endif -%}
     </td><td>{% if qualifier %}<strong>{{ qualifier|e }}:</strong>{% endif %}
       <em>{{ description|e }}</em></td></tr>
     {%- endfor %}
   {%- endfor %}
   </table>
</div>
{% endblock %}
